__author__ = """Jean-Paul Ladage <j.ladage@zestsoftware.nl>"""
__docformat__ = 'plaintext'

# Classes
import contract
import letter

contract, letter  # pyflakes
